@@ -1,12 +1,11 @@
 package App::Scaffolder::CommandTest::puppetmoduleTest;
-use parent qw(Test::Class);
+use parent qw(App::Scaffolder::Puppet::TestBase);
 
 use strict;
 use warnings;
 
 use Carp;
 use Test::More;
-use Test::Exception;
 use App::Cmd::Tester;
 use Path::Class::Dir;
 use Test::File;
@@ -17,6 +16,7 @@ use Directory::Scratch;
 use App::Scaffolder;
 use App::Scaffolder::Command::puppetmodule;
 
+
 sub app_test : Test(7) {
 	my ($self) = @_;
 
@@ -39,19 +39,4 @@ sub app_test : Test(7) {
 }
 
 
-sub get_extra_template_dirs_test : Test(2) {
-	my ($self) = @_;
-
-	my $sharedir = Path::Class::Dir->new(qw(share));
-	my $cmd = App::Scaffolder::Command::puppetmodule->new({});
-	local $ENV{SCAFFOLDER_TEMPLATE_PATH} = $sharedir->stringify();
-	my @template_dirs = $cmd->get_extra_template_dirs('puppetmodule');
-	cmp_ok(scalar @template_dirs, '>=', 1, 'at least one template dir found');
-	is(
-		scalar(grep { $_ eq $sharedir->subdir('puppetmodule')->stringify() } @template_dirs),
-		1,
-		'path from environment respected'
-	);
-}
-
 1;
